<?php
/**
 * beautytemple functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package beautytemple
 */

if ( ! function_exists( 'beautytemple_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function beautytemple_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on beautytemple, use a find and replace
		 * to change 'beautytemple' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'beautytemple', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'beautytemple' ),
			'menu-2' => esc_html__( 'Footer', 'beautytemple' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'beautytemple_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'beautytemple_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function beautytemple_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'beautytemple_content_width', 640 );
}
add_action( 'after_setup_theme', 'beautytemple_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function beautytemple_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'beautytemple' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'beautytemple' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h5 class="widget-heading">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'beautytemple_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function beautytemple_scripts() {
	wp_enqueue_style( 'beautytemple-style', get_stylesheet_uri() );

	wp_enqueue_style( 'beautytemple-main-style', get_stylesheet_directory_uri() . '/css/main.css', array(), array(), 'all' );
	wp_enqueue_style( 'beautytemple-tailwind-style', get_stylesheet_directory_uri() . '/tailwind.dist.css', array(), array(), 'all' );

	// wp_enqueue_style( 'beautytemple-main-style', get_stylesheet_directory_uri() . '/css/normalize.css', array(), array(), 'all' );

	// wp_enqueue_style( 'montserrat', esc_url('//fonts.googleapis.com/css?family=Montserrat:400,400i,700,700i'), array(), array(), 'all' );

	// wp_enqueue_style( 'playfair-display', esc_url('//fonts.googleapis.com/css?family=Playfair+Display'), array(), array(), 'all' );

	wp_enqueue_style( 'source-sans-pro', esc_url('//use.typekit.net/aor1ozm.css'), array(), array(), 'all' );

	wp_enqueue_style( 'fontawesome', esc_url('//use.fontawesome.com/releases/v5.1.0/css/all.css'), array(), array(), 'all' );

	wp_enqueue_script( 'modernizrn', get_template_directory_uri() . '/js/vendor/modernizr-3.6.0.min.js', array(), array(), true );

	wp_enqueue_script( 'beautytemple-plugins', get_template_directory_uri() . '/js/plugins.js', array('jquery'), array(), true );

	wp_enqueue_script( 'beautytemple-main', get_template_directory_uri() . '/js/main.js', array('jquery', 'beautytemple-plugins'), array(), true );


	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'beautytemple_scripts' );

/**
 * Kirki Init
 */
require get_template_directory() . '/inc/kirki-init.php';
/**
 * TGM Plugin Activator Init
 */
require get_template_directory() . '/inc/tgm-init.php';

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

